==> chewie-0.0.1.tar.gz: chewie-0.0.1/test/test_eap.py <==
import unittest
from netils import build_byte_string
from chewie.eap import Eap, EapIdentity, EapMd5Challenge, EapSuccess, EapFailure

class EapTestCase(unittest.TestCase):
    def test_eap_identity_parses(self):
        packed_message = build_byte_string("0101000501")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertEqual(message.identity, "")

    def test_eap_md5_challenge_parses(self):
        packed_message = build_byte_string("0201002204103a535f0ee8c6b34fe714aa7dad9a0e154a6f686e2e4d63477569726b")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertEqual(message.challenge, build_byte_string("3a535f0ee8c6b34fe714aa7dad9a0e15"))
        self.assertEqual(message.extra_data, b"John.McGuirk")

    def test_eap_identity_packs(self):
        expected_packed_message = build_byte_string("0101000501")
        eap = EapIdentity(Eap.REQUEST, 1, "")
        packed_message = eap.pack()
        self.assertEqual(expected_packed_message, packed_message)

    def test_eap_md5_challenge_packs(self):
        expected_packed_message = build_byte_string("0201002204103a535f0ee8c6b34fe714aa7dad9a0e154a6f686e2e4d63477569726b")
        eap = EapMd5Challenge(Eap.RESPONSE, 1, build_byte_string("3a535f0ee8c6b34fe714aa7dad9a0e15"), b"John.McGuirk")
        packed_message = eap.pack()
        self.assertEqual(expected_packed_message, packed_message)

    def test_eap_success_parses(self):
        packed_message = build_byte_string("03010004")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertTrue(isinstance(message, EapSuccess))

    def test_eap_failure_parses(self):
        packed_message = build_byte_string("04010004")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertTrue(isinstance(message, EapFailure))

==> chewie-0.0.8.tar.gz: chewie-0.0.8/test/test_eap.py <==

# pylint: disable=missing-docstring

import unittest
from netils import build_byte_string
from chewie.eap import Eap, EapIdentity, EapMd5Challenge, EapSuccess, EapFailure


class EapTestCase(unittest.TestCase):
    def test_eap_identity_parses(self):
        packed_message = build_byte_string("0101000501")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertEqual(message.identity, "")

    def test_eap_md5_challenge_parses(self):
        packed_message = build_byte_string(
            "0201002204103a535f0ee8c6b34fe714aa7dad9a0e154a6f686e2e4d63477569726b")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertEqual(message.challenge, build_byte_string("3a535f0ee8c6b34fe714aa7dad9a0e15"))
        self.assertEqual(message.extra_data, b"John.McGuirk")

    def test_eap_identity_packs(self):
        expected_packed_message = build_byte_string("0101000501")
        eap = EapIdentity(Eap.REQUEST, 1, "")
        packed_message = eap.pack()
        self.assertEqual(expected_packed_message, packed_message)

    def test_eap_md5_challenge_packs(self):
        expected_packed_message = build_byte_string(
            "0201002204103a535f0ee8c6b34fe714aa7dad9a0e154a6f686e2e4d63477569726b")
        eap = EapMd5Challenge(Eap.RESPONSE,
                              1,
                              build_byte_string("3a535f0ee8c6b34fe714aa7dad9a0e15"),
                              b"John.McGuirk")
        packed_message = eap.pack()
        self.assertEqual(expected_packed_message, packed_message)

    def test_eap_success_parses(self):
        packed_message = build_byte_string("03010004")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertTrue(isinstance(message, EapSuccess))

    def test_eap_failure_parses(self):
        packed_message = build_byte_string("04010004")
        message = Eap.parse(packed_message)
        self.assertEqual(message.packet_id, 1)
        self.assertTrue(isinstance(message, EapFailure))
